How does MEDS-Tab Work?
=======================

.. include:: ../../README.md
   :parser: markdown
   :start-after: How does MEDS-Tab Work?
   :end-before: Computational Performance vs. Existing Pipelines
